@@ -19,9 +19,9 @@ DATABASES = {{
         default="sqlite://./{shrine_name}.sqlite")}}
 
 if PRODUCTION:
-    DATABASES['default']['OPTIONS'] = {
+    DATABASES['default']['OPTIONS'] = {{
         'autocommit': True,
-    }
+    }}
 
 TEMPLATE_PATH = "./templates"
 STATIC_PATH = "./media"
